import * as d3 from 'd3';
// inspired by https://observablehq.com/@observablehq/d3-scatterplot 
// and by documentation https://github.com/d3/d3/blob/main/API.md
function renderData(dataElements) {

    let width = 600;
    let height = 400;
    let offset = 200;

    let tickets = dataElements.map(o => parseInt(o.Tickets) / 10000000);
    let income = dataElements.map(o => parseInt(o.Total) / 10000000);
    let data = dataElements.map(o => ({ tickets: parseInt(o.Tickets) / 10000000, income: parseInt(o.Total) / 10000000 }));

    let margin = ({ top: 25, right: 20, bottom: 35, left: 40 })

    let x = d3.scaleLinear()
        .domain([0, d3.max(income)]).nice()
        .range([margin.left, width - margin.right]);

    let y = d3.scaleLinear()
        .domain([0, d3.max(tickets)]).nice()
        .range([height - margin.bottom, margin.top]);
  
		// function with g arg assigned to xAxis
    let xAxis = g => g
      	.attr("transform", `translate(0,${height - margin.bottom})`)
        .call(d3.axisBottom(x));

  	// function with g arg assigned to yAxis
    let yAxis = g => g
        .attr("transform", `translate(${margin.left},0)`)
        .call(d3.axisLeft(y));

    const svg = d3.select("body").append("svg")
        .attr("viewBox", [-10, -20, width*1.6 , height*1.1]);

    svg.append("g")
        .call(xAxis);

    svg.append("g")
        .call(yAxis);

    svg.append("g")
        .selectAll("circle")
        .data(data)
        .join("circle")
        .attr("fill", "seagreen")
        .attr("cx", d => x(d.income))
        .attr("cy", d => y(d.tickets))
        .attr("r", 3);

    svg.append('text')
        .attr("fill", "black")
        .attr("x", width - 350)
        .attr("y", height - 3)
        .style("font-size", "14px")
        .text("Income in Millions");

    svg.append("text")
        .attr("fill", "black")
        .attr("x", "150")
        .attr("y", "-10")
        .attr("transform", "translate(30, 400) rotate(270)")
        .style("font-size", "14px")
        .text("Tickets in Millions");

    svg.append("text")
        .attr("fill", "black")
        .attr("x", width - 450)
        .attr("y", "5")
        .style("font-size", "18px")
        .text("Income to Tickets Sold of the Movie of the Year.");

    svg.append("text")
        .attr("fill", "black")
        .attr("x", width - 450)
        .attr("y", "20")
        .style("font-size", "12px")
        .text("1995 - 2021 years.");
}

d3.csv(
    "https://gist.githubusercontent.com/olga-kondr/54eea3576131d0c4ae30d7e180823b68/raw/bdae4f3380f890fbb2522dc5e3b5d19a1ee60351/Tickets_sold.csv"
).then(data => renderData(data));